@@ -55,6 +55,11 @@ try:
 except ImportError as error:
     get_xyz_along = error
 
+try:
+    from ..Methods.VectorField.get_vectorfield_along import get_vectorfield_along
+except ImportError as error:
+    get_vectorfield_along = error
+
 try:
     from ..Methods.VectorField.plot_2D_Data import plot_2D_Data
 except ImportError as error:
@@ -75,6 +80,16 @@ try:
 except ImportError as error:
     time_to_freq = error
 
+try:
+    from ..Methods.VectorField.to_xyz import to_xyz
+except ImportError as error:
+    to_xyz = error
+
+try:
+    from ..Methods.VectorField.to_rphiz import to_rphiz
+except ImportError as error:
+    to_rphiz = error
+
 
 from ._check import InitUnKnowClassError
 
@@ -176,6 +191,18 @@ class VectorField(FrozenClass):
         )
     else:
         get_xyz_along = get_xyz_along
+    # cf Methods.VectorField.get_vectorfield_along
+    if isinstance(get_vectorfield_along, ImportError):
+        get_vectorfield_along = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use VectorField method get_vectorfield_along: "
+                    + str(get_vectorfield_along)
+                )
+            )
+        )
+    else:
+        get_vectorfield_along = get_vectorfield_along
     # cf Methods.VectorField.plot_2D_Data
     if isinstance(plot_2D_Data, ImportError):
         plot_2D_Data = property(
@@ -221,6 +248,24 @@ class VectorField(FrozenClass):
         )
     else:
         time_to_freq = time_to_freq
+    # cf Methods.VectorField.to_xyz
+    if isinstance(to_xyz, ImportError):
+        to_xyz = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use VectorField method to_xyz: " + str(to_xyz))
+            )
+        )
+    else:
+        to_xyz = to_xyz
+    # cf Methods.VectorField.to_rphiz
+    if isinstance(to_rphiz, ImportError):
+        to_rphiz = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use VectorField method to_rphiz: " + str(to_rphiz))
+            )
+        )
+    else:
+        to_rphiz = to_rphiz
     # save and copy methods are available in all object
     save = save
     copy = copy
